##  Fact Sheet Attributes
The table below lists the fact sheet attributes for IT components provided by the reference catalog.
Base Attributes | Additional Attributes Available with SAP LeanIX Technology Risk and Compliance
---|---
  * Name and Description
  * IT Component Subtype
  * Release
  * Component Website
  * Relations to other catalog items
  * As of Date
  * External ID

| Lifecycle information (dates, URLs, support policies, and more)


